import { computed, ref } from "./vue.esm-browser";

async function fetchData(timeout: number = 2000) {
  return new Promise(async (resolve, reject) => {
    try {
      const res = await fetch(
        `https://diseases.sh/v3/covid-19/countries/?yesterday=true&strict=true`
      );
      setTimeout(async () => {
        resolve(await res.json());
      }, timeout);
    } catch (err) {
      reject(err);
    }
  });
}

export default {
  name: "CovidByCountry",
  props: {
    timeout: {
      type: Number,
      default: 3000
    }
  },
  async setup(props: any) {
    const data = ref(null);
    const error = ref(null);

    try {
      data.value = await fetchData(props.timeout);
    } catch (err) {
      error.value = err;
    }

    return {
      covid: computed(() => {
        return data.value;
      }),
      error
    };
  },
  template: `
    <div class="space-up error center" v-if="error">{{ error }}</div>
    <div v-else class="covid">
      <div class="covid-line" v-for="record in covid" :key="record.countryInfo._id">
        <span class="covid-country">{{ record.country }}</span>
        <ul>
          <li>Cases: {{ record.cases }}</li>
          <li>Recovered: {{ record.recovered }}</li>
          <li>Active: {{ record.active }}</li>
        </ul>
      </div>
    </div>
  `
};
