import { createApp, onErrorCaptured, ref } from "./vue.esm-browser";
import CovidByCountry from "./CovidByCountry";

const App = {
  components: {
    "covid-by-country": CovidByCountry
  },
  setup() {
    const timeout = ref(4000);
    const error = ref(null);

    onErrorCaptured((e: Error) => (error.value = e));

    return {
      error,
      timeout
    };
  },
  template: `
    <h1>COVID-19 Dashboard</h1>
    <div class="app">
      <h3>Data by Country</h3>
      <div class="space-up error" v-if="error">{{ error }}</div>
      <Suspense v-else>
        <template #default>
          <covid-by-country :timeout="timeout" />
        </template>
        <template #fallback>
          <div class="space-up">
            Loading please wait ...
          </div>
        </template>
      </Suspense>
    </div>
  `
};

createApp(App).mount("#app");
