import { createApp, ref } from "./vue.esm-browser";

const SampleThree = {
  name: "Sample Three",
  async setup() {
    const data = ref(null);

    try {
      data.value = await fetchData();
    } catch (e) {
      console.log(e);
    }

    return {
      data
    };
  },
  template: `
    <p style="text-align: center; padding-top: 20px;">This component is rendered without any data fetched!</p>
    <pre>{{ data }}</pre>
  `
};

const App = {
  components: {
    SampleThree
  },
  template: `
    <h1>Vue 3 Suspense</h1>
    <div class="app">
      <h3>Async/Promise with Success</h3>
      <Suspense>
        <template #default>
          <SampleThree />
        </template>
        <template #fallback>
          <div style="text-align: center; padding-top: 20px;">
            Loading please wait ...
          </div>
        </template>
      </Suspense>
    </div>
  `
};

createApp(App).mount("#app");

// Utils

async function fetchData() {
  return new Promise(async (resolve, reject) => {
    try {
      const res = await fetch(
        `https://diseases.sh/v3/covid-19/countries/?yesterday=true&strict=true`
      );
      setTimeout(async () => resolve(await res.json()), 2000);
    } catch {
      reject("Failed to load data");
    }
  });
}
